@@ -33,7 +33,7 @@ class MoFilter(logging.Filter):
         return True
 
 
-class Logger(object):
+class Logger:
     """print log to log file and stdout.
 
     log directory will be placed under
@@ -69,7 +69,7 @@ class Logger(object):
             "fulltrace": logging.INFO,
             "error": logging.ERROR,
         },
-        log_format="%(asctime)s %(lvl)s %(message)s"
+        log_format="%(asctime)s %(process)d:%(thread)d %(lvl)s %(message)s"
     ):
         super(Logger, self).__init__()
 
@@ -87,7 +87,7 @@ class Logger(object):
         # {
         #    name: handler
         # }
-        self._filehandlers = {}
+        self._handlers = {}
 
         # setup logger
         self.open()
@@ -116,6 +116,7 @@ class Logger(object):
                 stdout.setLevel(logging.NOTSET)
                 stdout.setFormatter(formatter)
                 self._logger.addHandler(stdout)
+                self._handlers["stdout"] = stdout
 
             # add file handlers to logger
             if len(self.outputs) > 0:
@@ -135,7 +136,7 @@ class Logger(object):
                         encoding="utf-8")
                     handler.setLevel(level)
                     handler.setFormatter(formatter)
-                    self._filehandlers[name] = handler
+                    self._handlers[name] = handler
                     self._logger.addHandler(handler)
 
             self._closed = False
@@ -154,7 +155,7 @@ class Logger(object):
         if not self._closed:
             try:
                 self._flush_count = 0
-                for handler in self._filehandlers.values():
+                for handler in self._handlers.values():
                     # handler calls flush() in close()
                     handler.close()
                     self._logger.removeHandler(handler)
@@ -210,7 +211,7 @@ class Logger(object):
     def flush(self):
         """flush messages to handlers"""
 
-        for handler in self._filehandlers.values():
+        for handler in self._handlers.values():
             handler.flush()
         self._flush_count = 0
 
@@ -219,7 +220,7 @@ class Logger(object):
         returns None.
         """
 
-        return self._filehandlers.get(name)
+        return self._handlers.get(name)
 
 
 class StdoutToFileLogger(Logger):
